fastapi\_contrib.db package
===========================

Submodules
----------

fastapi\_contrib.db.client module
---------------------------------

.. automodule:: fastapi_contrib.db.client
    :members:
    :undoc-members:
    :show-inheritance:

fastapi\_contrib.db.models module
---------------------------------

.. automodule:: fastapi_contrib.db.models
    :members:
    :undoc-members:
    :show-inheritance:

fastapi\_contrib.db.serializers module
--------------------------------------

.. automodule:: fastapi_contrib.db.serializers
    :members:
    :undoc-members:
    :show-inheritance:

fastapi\_contrib.db.utils module
--------------------------------

.. automodule:: fastapi_contrib.db.utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: fastapi_contrib.db
    :members:
    :undoc-members:
    :show-inheritance:
